@@ -3,4 +3,6 @@ from H_MCRLLM.half_mcr import *
 from H_MCRLLM.mcrllm import *
 from H_MCRLLM.pointselector import * 
 from H_MCRLLM.preprocessing import *
-from H_MCRLLM.select_with_PCA import *
\ No newline at end of file
+from H_MCRLLM.select_with_PCA import *
+from H_MCRLLM.use_half_mcr import *
+from H_MCRLLM.use_full_mcr import *
\ No newline at end of file
